==> v3.42.tar.gz: combo/combo/apps/gallery/views.py <==
# combo - content management system
# Copyright (C) 2015  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.shortcuts import redirect
from django.urls import reverse, reverse_lazy
from django.views.generic import (
    CreateView,
    DeleteView,
    DetailView,
    FormView,
    ListView,
    RedirectView,
    TemplateView,
    UpdateView,
)

from .forms import ImageAddForm, ImageEditForm
from .models import GalleryCell, Image


class ImageAddView(CreateView):
    model = Image
    template_name = 'combo/gallery_image_form.html'
    form_class = ImageAddForm

    def form_valid(self, form):
        form.instance.gallery_id = self.kwargs.get('gallery_pk')
        other_images = form.instance.gallery.image_set.all()
        if other_images:
            form.instance.order = max([x.order for x in other_images]) + 1
        else:
            form.instance.order = 0
        return super(ImageAddView, self).form_valid(form)

    def get_success_url(self):
        return (
            reverse('combo-manager-page-view', kwargs={'pk': self.object.gallery.page.id})
            + '#cell-'
            + self.object.gallery.get_reference()
        )


image_add = ImageAddView.as_view()


class ImageEditView(UpdateView):
    model = Image
    template_name = 'combo/gallery_image_form.html'
    form_class = ImageEditForm

    def get_success_url(self):
        return (
            reverse('combo-manager-page-view', kwargs={'pk': self.object.gallery.page.id})
            + '#cell-'
            + self.object.gallery.get_reference()
        )


image_edit = ImageEditView.as_view()


def image_delete(request, gallery_pk, pk):
    gallery = GalleryCell.objects.get(id=gallery_pk)
    Image.objects.get(id=pk).delete()
    return redirect(reverse('combo-manager-page-view', kwargs={'pk': gallery.page.id}))


def image_order(request, gallery_pk):
    gallery = GalleryCell.objects.get(id=gallery_pk)
    new_order = [int(x) for x in request.GET['new-order'].split(',')]
    for image in gallery.image_set.all():
        image.order = new_order.index(image.id) + 1
        image.save()
    return redirect(reverse('combo-manager-page-view', kwargs={'pk': gallery.page.id}))

==> v3.81.tar.gz: combo/combo/apps/gallery/views.py <==
# combo - content management system
# Copyright (C) 2015  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.shortcuts import redirect
from django.urls import reverse
from django.views.generic import CreateView, UpdateView

from .forms import ImageAddForm, ImageEditForm
from .models import GalleryCell, Image


class ImageAddView(CreateView):
    model = Image
    template_name = 'combo/gallery_image_form.html'
    form_class = ImageAddForm

    def form_valid(self, form):
        form.instance.gallery_id = self.kwargs.get('gallery_pk')
        other_images = form.instance.gallery.image_set.all()
        if other_images:
            form.instance.order = max(x.order for x in other_images) + 1
        else:
            form.instance.order = 0
        return super().form_valid(form)

    def get_success_url(self):
        return (
            reverse('combo-manager-page-view', kwargs={'pk': self.object.gallery.page.id})
            + '#cell-'
            + self.object.gallery.get_reference()
        )


image_add = ImageAddView.as_view()


class ImageEditView(UpdateView):
    model = Image
    template_name = 'combo/gallery_image_form.html'
    form_class = ImageEditForm

    def get_success_url(self):
        return (
            reverse('combo-manager-page-view', kwargs={'pk': self.object.gallery.page.id})
            + '#cell-'
            + self.object.gallery.get_reference()
        )


image_edit = ImageEditView.as_view()


def image_delete(request, gallery_pk, pk):
    gallery = GalleryCell.objects.get(id=gallery_pk)
    Image.objects.get(id=pk).delete()
    return redirect(reverse('combo-manager-page-view', kwargs={'pk': gallery.page.id}))


def image_order(request, gallery_pk):
    gallery = GalleryCell.objects.get(id=gallery_pk)
    new_order = [int(x) for x in request.GET['new-order'].split(',')]
    for image in gallery.image_set.all():
        image.order = new_order.index(image.id) + 1
        image.save()
    return redirect(reverse('combo-manager-page-view', kwargs={'pk': gallery.page.id}))
